@@ -9,11 +9,11 @@ use File::Spec::Functions ();
 use IO::File;
 use Moo;
 use File::ShareDir::ProjectDistDir;
-use Unicode::CaseFold;
 
-our $VERSION = '0.02.01'; # VERSION
+our $VERSION = '0.001'; # VERSION
 
-has dict => ( is => q(rw), default => sub { {}; }, );
+has share_dir => ( is => q(ro), default => sub { }, );
+has dict      => ( is => q(rw), default => sub { {}; }, );
 has language  => ( is => q(rw) );
 has domain    => ( is => q(rw) );
 has subdomain => ( is => q(rw) );
@@ -22,9 +22,7 @@ sub BUILD {
     my $self = shift;
     my $args = shift;
 
-    my $pkg = __PACKAGE__;
-    $pkg =~ s{::}{-}g;
-    my $share_dir = dist_dir($pkg);
+    my $share_dir = dist_dir(__PACKAGE__);
     my @dict_file;
     find( sub { push @dict_file, $File::Find::name if -e }, $share_dir, );
 
@@ -108,7 +106,7 @@ sub _proc_results {
 
     my @result;
     foreach my $result ( @{$results} ) {
-        if ( defined $mode && $mode eq q(with_origin) ) {
+        if ( $mode ~~ q(with_origin) ) {
             push @result, { $result => $origin };
         }
         else {
@@ -147,7 +145,7 @@ Text::UnAbbrev - Expand abbreviations and acronyms.
 
 =head1 VERSION
 
-version 0.02.01
+version 0.001
 
 =head1 SYNOPSIS
 
